Distribution:   CCux
Packager:	Christian Wasem <wasem@ccux-linux.de>

Name:		mysql
Summary:        MySQL is a very fast and reliable SQL database server
Version:	5.1.48
Release:	1
BuildArch:	i686
License: 	GPLv2 with exceptions
URL:		http://www.mysql.com
Group:		Databases
Source0:	%{name}-%{version}.tar.gz
Source201:	mysql.init
Source202:	my.cnf
Source299: 	filter-requires-mysql.sh
Patch0:		mysql-sqlbenchdir.patch
Requires(post,preun): /sbin/install-info
Requires(post,preun): /sbin/chkconfig

%define		mysql_datadir	/var/lib/mysql
%define		mysql_user	mysql
%define		mysql_group	mysql

# Working around perl dependency checking bug in rpm FTTB. Remove later.
%define __perl_requires %{SOURCE299}

BuildRequires: readline-devel

#Automatically resolved build dependencies
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libstdc++-devel
BuildRequires: ncurses-devel
BuildRequires: openssl-devel
BuildRequires: perl
BuildRequires: perl-DBI
BuildRequires: readline-devel
BuildRequires: zlib-devel tcp_wrappers-devel procps

%description
The MySQL(TM) software delivers a very fast, multi-threaded, multi-user,
and robust SQL (Structured Query Language) database server. MySQL Server
is intended for mission-critical, heavy-load production systems as well
as for embedding into mass-deployed software. MySQL is a trademark of
MySQL AB.

The MySQL software has Dual Licensing, which means you can use the MySQL
software free of charge under the GNU General Public License
(http://www.gnu.org/licenses/). You can also purchase commercial MySQL
licenses from MySQL AB if you do not wish to be bound by the terms of
the GPL. See the chapter "Licensing and Support" in the manual for
further info.

The MySQL web site (http://www.mysql.com/) provides the latest
news and information about the MySQL software. Also please see the
documentation and the manual for more information.

%package	devel
Summary:	%{name} development headers.
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description	devel
Header and include files for developing applications with %{name}.

%package embedded

Summary: 	MySQL as an embeddable library
Group: 		Databases

%description embedded
MySQL is a multi-user, multi-threaded SQL database server. This
package contains a version of the MySQL server that can be embedded
into a client application instead of running as a separate process.

%package embedded-devel

Summary: 	Development files for MySQL as an embeddable library
Group: 		Databases
Requires: 	%{name}-embedded = %{version}-%{release}
Requires:	%{name}-devel = %{version}-%{release}

%description embedded-devel
MySQL is a multi-user, multi-threaded SQL database server. This
package contains files needed for developing and testing with
the embedded version of the MySQL server.

%pre
groupadd -g 50 %{mysql_group} > /dev/null 2>&1 || :
/usr/sbin/useradd -o -r -d /var/lib/mysql -s /bin/bash \
	-c "MySQL Server" -g %{mysql_group} -u 50 %{mysql_user} > /dev/null 2>&1 || :



%post
# Install info files
/sbin/install-info %_infodir/mysql.info.gz %_infodir/dir
ldconfig
# Add to init process and activate
/sbin/chkconfig --add mysql
/sbin/chkconfig mysql on
# Restart mysql if we are upgrading...
if test $1 -gt 1; then
        /etc/rc.d/init.d/mysql stop 1>/dev/null 2>&1
        /etc/rc.d/init.d/mysql start 1>/dev/null 2>&1
fi

%preun
# Stop mysql and remove initscript 
if test $1 = 0; then
        /etc/rc.d/init.d/mysql stop 1>/dev/null 2>&1
        /sbin/chkconfig --del mysql
fi
# Remove User/Group only when removing finally
if [ $1 -eq 0 ]; then
    /usr/sbin/userdel %{mysql_user} &>/dev/null || :
    /usr/sbin/groupdel %{mysql_group} &>/dev/null || :
fi
# Remove info files
if [ "$1" = 0 ]; then
    /sbin/install-info --del %_infodir/mysql.info.gz %_infodir/dir
fi 

%postun
rm -fR %{mysql_datadir}
ldconfig

%prep
%setup -qn %{name}-%{version}
%patch0 -p1

%build
./configure --prefix=%_prefix \
	--sysconfdir=%_sysconfdir \
	--mandir=%_mandir \
	--infodir=%_infodir \
	--libexecdir=%_sbindir \
	--localstatedir=%{mysql_datadir} \
	--enable-thread-safe-client \
	--enable-assembler \
	--enable-local-infile \
	--with-named-thread-libs=-lpthread \
	--with-unix-socket-path=/var/lib/mysql/mysql.sock \
	--with-mysqld-user="%{mysql_user}" \
	--without-debug \
	--with-readline \
	--with-libwrap \
	--with-ssl \
	--without-bench \
	--with-extra-charsets=all \
	--disable-dependency-tracking \
	--with-embedded-server \
	--enable-shared \
	--with-big-tables \
	--with-pic \
        --with-plugin-innobase \
        --without-plugin-innodb_plugin \
        --with-plugin-partition \
	--enable-largefile 

make %{?_smp_mflags}

mkdir libmysqld/work
cd libmysqld/work
ar -x ../libmysqld.a
gcc $CFLAGS $LDFLAGS -shared -Wl,-soname,libmysqld.so.0 -o libmysqld.so.0.0.1 \
	*.o \
	-lpthread -lcrypt -lnsl -lssl -lcrypto -lz -lrt -lstdc++ -lm -lc
ln -s libmysqld.so.0.0.1 libmysqld.so.0
cd ../..


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Creating required directories
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/var/run/mysqld
install -m 0755 -d $RPM_BUILD_ROOT/var/lib/mysql
# Copy initscript to init.d
install -m 755 %{SOURCE201} $RPM_BUILD_ROOT%_sysconfdir/rc.d/init.d/%{name}
# Add mysql configuration to /etc
install -m644 %{SOURCE202} $RPM_BUILD_ROOT%_sysconfdir/my.cnf
mkdir -p $RPM_BUILD_ROOT/var/log
touch $RPM_BUILD_ROOT/var/log/mysqld.log
echo %{version} > $RPM_BUILD_ROOT/var/lib/mysql/.install
echo %{version} > $RPM_BUILD_ROOT/var/run/mysqld/.install

#rm -f ${RPM_BUILD_ROOT}%{_libdir}/mysql/libmysqld.a
install -m 0755 libmysqld/work/libmysqld.so.0.0.1 ${RPM_BUILD_ROOT}%{_libdir}/mysql/libmysqld.so.0.0.1
ln -s libmysqld.so.0.0.1 ${RPM_BUILD_ROOT}%{_libdir}/mysql/libmysqld.so.0
ln -s libmysqld.so.0 ${RPM_BUILD_ROOT}%{_libdir}/mysql/libmysqld.so
ln -s mysql/libmysqld.so.0.0.1 ${RPM_BUILD_ROOT}%{_libdir}/libmysqld.so.0

# Creating sharing libraries for other programms
cd $RPM_BUILD_ROOT%_libdir
ln -v -sf %{name}/libmysqlclient{,_r}.so* $RPM_BUILD_ROOT%_libdir

#mv $RPM_BUILD_ROOT/usr/sql-bench $RPM_BUILD_ROOT%{_datadir}/sql-bench

# Remove mysql-test directory
rm -R $RPM_BUILD_ROOT%_prefix/%{name}-test
#rm -f ${RPM_BUILD_ROOT}%{_libdir}/mysql/plugin/*.la
#rm -f ${RPM_BUILD_ROOT}%{_libdir}/mysql/plugin/*.a


%files
%defattr(-,root,root)
%config(noreplace) %_sysconfdir/my.cnf
%_sysconfdir/rc.d/init.d/%{name}
%attr(0755,mysql,mysql) %dir /var/run/mysqld
%attr(0755,mysql,mysql) %dir /var/lib/mysql
%attr(0640,mysql,mysql) %config(noreplace) %verify(not md5 size mtime) /var/log/mysqld.log
/var/lib/mysql/.install
/var/run/mysqld/.install
%_bindir
%_sbindir
%_libdir/*.so
%_libdir/*.so.*
%_libdir/%{name}/*.so
%_libdir/%{name}/*.so.*
%_datadir
%exclude %{_libdir}/%{name}/libmysqld.so.*
%exclude %{_libdir}/%{name}/libmysqld.so
%exclude %{_bindir}/mysql_client_test_embedded
%exclude %{_bindir}/mysqltest_embedded
%exclude %{_mandir}/man1/mysql_client_test_embedded.1*
%exclude %{_mandir}/man1/mysqltest_embedded.1*
%exclude %_libdir/libmysqld.so.*
%{_libdir}/mysql/plugin

%files devel
%defattr(-,root,root)
%_includedir
%_libdir/%{name}/*.a
%_libdir/%{name}/*.la
%exclude %_libdir/%{name}/libmysqld.a

%files embedded
%defattr(-,root,root)
%_libdir/%{name}/libmysqld.so.*
%_libdir/libmysqld.so.*

%files embedded-devel
%defattr(-,root,root)
%_libdir/%{name}/libmysqld.so
%_bindir/mysql_client_test_embedded
%_bindir/mysqltest_embedded
%_mandir/man1/mysql_client_test_embedded.1*
%_mandir/man1/mysqltest_embedded.1*
%_libdir/%{name}/libmysqld.a

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Sun Jul 18 2010 Karsten Brockmann <arcam@ccux-linux.de> 5.1.48-1
- Version update
* Mon May 31 2010 Karsten Brockmann <arcam@ccux-linux.de> 5.1.47-1
- Version update
* Tue Dec 08 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-7
- alter my.cnf to point to correct socket
* Tue Dec 08 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-6
- fix init script and move initial db setup to init script itself
* Tue Dec 08 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-5
- fix mysql user home dir
- fix creation of mysql directories
* Tue Dec 08 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-4
- fix directory ownerships
* Thu Jun 25 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-3
- fix mysql embedded symlink target
- fixes bug #0000036
* Tue Jun 23 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-2
- modified libmysqld symlink
* Mon Jun 22 2009 Christian Metzen <metzench@ccux-linux.de> 5.0.83-1
- Version update
* Wed Feb 25 2009 Karsten Brockmann <arcam@ccux-linux.de> 5.0.77-1
- Version update
* Fri Oct 17 2008 Christian Metzen <metzench@ccux-linux.de> 5.0.67-4
- added -lwrap
* Fri Oct 17 2008 Christian Metzen <metzench@ccux-linux.de> 5.0.67-3
- readded static embedded
* Fri Oct 17 2008 Christian Metzen <metzench@ccux-linux.de> 5.0.67-2
- rebuild without ccache
* Fri Oct 17 2008 Christian Metzen <metzench@ccux-linux.de> 5.0.67-1
- Version update
- added mysql embedded
* Sat May 17 2008 Christian Wasem <wasem@ccux-linux.de> 5.0.51b-3
- fixed wrong mysqld pid file in init-script
* Tue May 13 2008 Christian Wasem <wasem@ccux-linux.de> 5.0.51b-2
- fixed wrong mysql_datadir, specfile tweaking
* Mon May 05 2008 Karsten Brockmann <arcam@ccux-linux.de> 5.0.51b-1
- Version update
* Thu Dec 13 2007 Karsten Brockmann <arcam@ccux-linux.de> 5.0.51-1
- Version update
* Fri Jan 19 2007 Christian Wasem <wasem@ccux-linux.de> 5.0.27-1
- Version update
* Wed Oct 11 2006 Karsten Brockmann <arcam@ccux-linux.de> 5.0.26-1
- Version update
- ported initscript to support chkconfig
* Sun Sep 11 2005 Christian Wasem <wasem@ccux-linux.de> 4.1.14-1
- Update to Version 4.1.14 for SourceRPM
